import Qt 4.7
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper

Widgets.PageFrame
{
	property variant context

	onContextChanged:
	{
		showFirstPage();
	}

	id: wizard
	objectName: "activationWizard"

	property variant fontStyles:			Fonts.LicenseFonts{}
	property variant standartFontStyles:	Fonts.Common{}
	property variant currentPage

	property alias headerText:				headerText.text

	backButtonVisible:		true
	backButtonEnabled:		listPages.count && ((wizard.currentPage && wizard.currentPage.backButtonEnabled) ? wizard.currentPage.backButtonEnabled : false);
	backButtonText:			(wizard.currentPage && wizard.currentPage.backButtonText) ? wizard.currentPage.backButtonText : context.Localize("BackButton")

	nextButtonVisible:		true
	nextButtonEnabled:		(wizard.currentPage && wizard.currentPage.nextButtonEnabled) ? wizard.currentPage.nextButtonEnabled : false;
	nextButtonText:			(wizard.currentPage && wizard.currentPage.nextButtonText) ? wizard.currentPage.nextButtonText : context.Localize("NextButton")

	cancelButtonVisible:	true
	cancelButtonEnabled:	(wizard.currentPage && wizard.currentPage.cancelButtonEnabled) ? wizard.currentPage.cancelButtonEnabled : false
	cancelButtonText:		(wizard.currentPage && wizard.currentPage.cancelButtonText) ? wizard.currentPage.cancelButtonText : context.Localize("Cancel")

	helpButtonVisible:		wizard.currentPage ? wizard.currentPage.helpButtonVisible : true

	windowDescriptionText:	context.Title

	Connections {onHelp:		if (wizard.currentPage) wizard.currentPage.onHelp();}
	Connections {onClose: 		if (wizard.currentPage) wizard.currentPage.onClose();}
	Connections {onBack:		if (wizard.currentPage) wizard.currentPage.onBack();}
	Connections {onNext:		if (wizard.currentPage) wizard.currentPage.onNext();}
	Connections {onCancel:		if (wizard.currentPage) wizard.currentPage.onCancel();}

	function showFirstPage()
	{
		if (EnumHelper.getKey(context, "ActivationState") != "ActivationState_Initial")
		{
			console.log("Can't create first page for: ActivationState = '" + EnumHelper.getKey(context, "ActivationState") + "'");
			return;
		}
		switch (EnumHelper.getKey(context, "ActivationReason"))
		{
			case "ActivationReason_NewLicense":
			case "ActivationReason_AddLicense":
			case "ActivationReason_FromKAVToCommercialKIS":			
				setNewPage(activationPageEdition, false);
				break;
			case "ActivationReason_ReserveCodeActivationOverActiveLicense":
				setNewPage(activationPageReservedCode, false);
				break;
			case "ActivationReason_ReserveCodeActivationOverInactiveLicense":
			case "ActivationReason_CheckReserveCode":
				setNewPage(activationPageProcessing, false);
				break;
			case "ActivationReason_SubscriptionUpdate":
				setNewPage(activationPageProcessing, false);
				break;
			case "ActivationReason_TrialKis":
				setNewPage(activationPageProcessing, false);
				break;
			case "ActivationReason_PreinstalledCodeActivation":
				setNewPage(activationPageProcessing, false);
				break;
			case "ActivationReason_LicenseFound":
				setNewPage(activationPageHasLicense, false);
				break;
			default:
				console.log("Can't create first page for: ActivationReason = '" + EnumHelper.getKey(context, "ActivationReason") + "'");
		}
	}

	function selectPageOnStateChanged(saveCurrentPage)
	{
		var page = undefined;
		switch (EnumHelper.getKey(context, "ActivationState"))
		{
			case "ActivationState_Undefined": return;
			case "ActivationState_Initial":
				page = activationPageEdition;
				break;
			case "ActivationState_Started":
				page = activationPageProcessing;
				break;
			case "ActivationState_Success":
				page = activationPageSucceed;
				break;
			case "ActivationState_FormDownloaded":
				page = activationPageRegistration;
				break;
			case "ActivationState_ServerNotAvailable":
				page = context.IsSubscriptionLicense() ? activationPageFailed : activationPageNoConnection;
				break;
			case "ActivationState_Error":
				page = activationPageFailed;
				break;
			case "ActivationState_KeyFromOtherProductDueReserve":
				page = activationPageOtherProductDueReserve;
				break;
			case "ActivationState_KeyFromOtherProductDueActivation":
				page = activationPageOtherProductDueActivation;
				break;
			case "ActivationState_KeyForSubscriptionOnly":
				page = activationPageSubscriptionReplace;
				break;
			default:
				console.log("Can't select page for: ActivationState = '" + EnumHelper.getKey(context, "ActivationState") + "'");
		}
		setNewPage(page, saveCurrentPage);
	}

	ListModel{id: listPages}
	function setNewPage(page, saveCurrentPage)
	{
		if (page == currentPage)
			return;

		if (currentPage)
			currentPage.visible = false;
		if (currentPage && saveCurrentPage)
			listPages.append({"page": currentPage});
		currentPage = page;
		currentPage.visible = true;
	}
	function backToPreviosPage()
	{
		if (!listPages.count)
			return;
		currentPage.visible = false;
		currentPage = listPages.get(listPages.count - 1).page;
		listPages.remove(listPages.count - 1);
		currentPage.visible = true;
		wizard.context.CancelActivation();
	}

	Item
	{
		id: workingArea
		objectName: "workingArea"

        property int topGap:	29
        property int bottomGap:	43 /* boottom border */
        property int leftGap:	164 /* banner width */  + 10 /*left border*/
        property int rightGap:	10 /* right border */

		x:		leftGap
		y:		topGap
		width:	parent.width - leftGap - rightGap
		height: parent.height - topGap - bottomGap


		Column
		{
			id:	header
			clip: true

			anchors.left:parent.left
			anchors.right:parent.right
			anchors.top: parent.top

			Item { width: parent.width; height: 30 }
			Widgets.StandardCaptionText
			{
				id: headerText

                property int marginWidth: 30
				anchors.left:	parent.left; anchors.leftMargin: marginWidth
				anchors.right:	parent.right; anchors.rightMargin: marginWidth

				text:	wizard.currentPage ? wizard.currentPage.headerString : ""
				wrapMode: Text.Wrap
			}
			Item { width: parent.width; height: 20 }
		}

		Rectangle
		{
			id: workingAreaSplitter
			anchors.left: parent.left
			anchors.leftMargin: 0
			anchors.right: parent.right
			anchors.rightMargin: 0
			anchors.top:	header.bottom
			height:			1
			color:			"#cccccc"
		}

		Item
		{
			width:	parent.width
			anchors.top:	workingAreaSplitter.bottom
			anchors.bottom: workingArea.bottom
			clip: true
			objectName: "pagesGroup"

			Item
			{
				id:			pagesWorkingArea
				objectName: "pagesWorkingArea"
				property int marginWidth:	30
				anchors.fill:				parent
				anchors.leftMargin:			marginWidth
				anchors.rightMargin:		marginWidth
				anchors.topMargin:			marginWidth
				anchors.bottomMargin:		marginWidth

				ActivationPageEdition		{id: activationPageEdition		;  context:wizard.context }
				ActivationPageHasLicense	{id: activationPageHasLicense	; context:wizard.context  }
				ActivationPageProcessing	{id: activationPageProcessing	; context:wizard.context  }
				ActivationPageSucceed		{id: activationPageSucceed		; context:wizard.context  }
				ActivationPageFailed		{id: activationPageFailed		; context:wizard.context  }
				ActivationPageNoConnection	{id: activationPageNoConnection	; context:wizard.context  }
				ActivationPageRegistration	{id: activationPageRegistration	; context:wizard.context  }
				ActivationPageReservedCode	{id: activationPageReservedCode	; context:wizard.context  }

				ActivationPageSubscriptionReplace		{id: activationPageSubscriptionReplace	; context:wizard.context  }

				ActivationPageOtherProductDueActivation	{id: activationPageOtherProductDueActivation; context:wizard.context  }
				ActivationPageOtherProductDueReserve	{id: activationPageOtherProductDueReserve	; context:wizard.context  }
			}
		}
	}
	Component.onCompleted:
	{
		wizard.context = MainWindow.activationWizard
	}
	
	Component.onDestruction:
	{
		wizard.context.FinalizeActivation()
	}
	
	Keys.onPressed: { if (event.key == Qt.Key_F1) if (wizard.currentPage) wizard.currentPage.onHelp(); }
}
