import Qt 4.7
import "../fonts" as Fonts

BaseButton
{
	id: button
	objectName: "button"

	property variant fontStyles: Fonts.Common{}

	property alias text:				buttonText.text
	property alias textfont:			buttonText.font
	property alias textStyle:			buttonText.style
	property alias textStyleColor:		buttonText.styleColor
	property variant textcolor:			"White"
	property variant textcolorHovered:	""
	property variant textcolorPressed:	""
	property variant textcolorDisabled:	"Gray"

	property variant backgroundImage:	""
	property variant hoverImage
	property variant pressedImage
	property variant disabledImage

	property variant iconImage:			""
	property variant iconHoverImage
	property variant iconPressedImage
	property variant iconDisabledImage

	property variant hoverEffectImage
	property variant pressedEffectImage
	property variant disabledEffectImage

	property int borderWidth:			(buttonText.paintedWidth && backgroundImage) ? 5 : 0
	property int borderLeft: 			borderWidth
	property int borderRight: 			borderWidth
	property int horizontalMargin: 		(buttonText.paintedWidth && backgroundImage) ? 5 : 0
	property int verticalMargin: 		(buttonText.paintedWidth && backgroundImage) ? 5 : 0
	property int spacing:				(buttonText.paintedWidth && icon.width) ? 5 : 0
    property real textVerticalOffset: 1

	property int minWidth
	property int maxWidth

	property int minHeight
	property int maxHeight

	property int buttonWidth
	property int buttonHeight

	property bool textBottom
	property bool textLeft

	function getSize(minSize, maxSize, textSize)
	{
		return Math.max(minSize, Math.min(textSize, maxSize ? maxSize : textSize));
	}
	function getAndUpdateWidthForTextRigth()
	{
		var marginWidth		= horizontalMargin * 2 + (icon.width ? spacing : 0);
		var widthForItems	= buttonText.paintedWidth + icon.width + marginWidth;
		var localWidth		= buttonWidth ? buttonWidth : getSize(minWidth, maxWidth, widthForItems);

		if (localWidth < widthForItems)
		{
			buttonText.width = localWidth - marginWidth - icon.width;
			widthForItems	= buttonText.paintedWidth + icon.width + marginWidth;
		}

		if (icon.width)
		{
			icon.anchors.leftMargin = textLeft ? horizontalMargin : Math.abs(localWidth - widthForItems)/2 + horizontalMargin;
			buttonText.anchors.leftMargin = spacing;
		}
		else
		{
			icon.anchors.leftMargin = 0;
			buttonText.anchors.leftMargin = textLeft ? horizontalMargin : Math.abs(localWidth - widthForItems)/2 + horizontalMargin;
		}

		return localWidth;
	}

	function getAndUpdateHeightForTextRigth()
	{
		var marginHeight	= verticalMargin * 2;
		var heightForItems	= Math.max(buttonText.paintedHeight, icon.height) + marginHeight;
		var localHeight		= buttonHeight ? buttonHeight : getSize(minHeight, maxHeight, heightForItems);

		return localHeight;
	}

	function getAndUpdateWidthForTextBottom()
	{
		var marginWidth = horizontalMargin * 2;
		var widthForItems = Math.max(buttonText.paintedWidth, icon.width) + marginWidth;
		var localWidth = buttonWidth ? buttonWidth : getSize(minWidth, maxWidth, widthForItems);

		return localWidth;
	}

	function getAndUpdateHeightForTextBottom()
	{
		var marginHeight = verticalMargin * 2 + (icon.height ? spacing : 0);
		var heightForItems = buttonText.paintedHeight + icon.height + marginHeight;
		var localHeight = buttonHeight ? buttonHeight : getSize(minHeight, maxHeight, heightForItems);

		if (icon.height)
		{
			icon.anchors.topMargin = Math.abs(localHeight - heightForItems)/2 + verticalMargin;
			buttonText.anchors.topMargin = spacing;
		}
		else
		{
			icon.anchors.topMargin = 0;
			buttonText.anchors.topMargin = Math.abs(localHeight - heightForItems) / 2 + verticalMargin;
		}

		return localHeight;
	}

	width: button.textBottom ? getAndUpdateWidthForTextBottom() : getAndUpdateWidthForTextRigth()
	height: button.textBottom ? getAndUpdateHeightForTextBottom() : getAndUpdateHeightForTextRigth()

	BorderImage
	{
		anchors.fill: parent
		source:	button.selectValue(button.disabledImage, button.backgroundImage, button.hoverImage, button.pressedImage)
		border { left: button.borderLeft; top: button.borderWidth; right: button.borderRight; bottom: button.borderWidth }
	}

	BorderImage
	{
		id:				hoverEffect
		anchors.fill:	parent
		source:			hoverEffectImage ? hoverEffectImage : ""
		visible:		selectValue(false, false, true, false)
	}
	BorderImage
	{
		id:				pressedEffect
		anchors.fill:	parent
		source:			pressedEffectImage ? pressedEffectImage : ""
		visible:		selectValue(false, false, false, true)
	}
	BorderImage
	{
		id:				disabledEffect
		anchors.fill:	parent
		source:			disabledEffectImage ? disabledEffectImage : ""
		visible:		!button.enabled
	}

	Image
	{
		id:					icon
		source:				selectValue(button.iconDisabledImage, button.iconImage, button.iconHoverImage, button.iconPressedImage)
		anchors.left:		button.textBottom ? undefined : parent.left
		anchors.top:		button.textBottom ? parent.top : undefined
		anchors.verticalCenter: button.textBottom ? undefined : parent.verticalCenter
		anchors.horizontalCenter: button.textBottom ? parent.horizontalCenter : undefined
	}
	Text
	{
		id:		buttonText
		font:		button.fontStyles.standardButtonFont
		elide:		Text.ElideRight
		color:		selectValue(textcolorDisabled, textcolor, textcolorHovered, textcolorPressed)
		clip: true
		verticalAlignment:	Text.AlignVCenter
		anchors.left:
		{
			if (button.textBottom)
				return undefined;
			if (icon.source && icon.source != "")
				return icon.right
			else
				return undefined
		}
		anchors.top:		button.textBottom ? icon.bottom : undefined
		anchors.verticalCenter: button.textBottom ? undefined : parent.verticalCenter
        anchors.verticalCenterOffset: button.textVerticalOffset
		anchors.horizontalCenter:
		{
			if (button.textBottom)
				return parent.horizontalCenter
			if (icon.source && icon.source != "")
				return undefined
			else
				return parent.horizontalCenter
		}
	}
}
